use strict;
use warnings;
package Skeletor::Template::Example;

our $VERSION = '0.003';

=head1 NAME

Skeletor::Template::Example - An example template skel for Skeletor

=head1 SYNOPSIS

    skeletor --template Skeletor::Template::Example \
      --as Local::MyApp \
      --directory ~/new_projects \
      --author 'John Napiorkowski <jjnapiork@cpan.org>' \
      --year 2015

=head1 DESCRIPTION

This is an example L<App::Skeletor> template project skel for use to learn how to
use the tool and to build custom skeleton projects of your own.

=head1 TEMPLATE VARIABLES

See L<App::Skeletor>

=head1 AUTHOR
 
John Napiorkowski L<email:jjnapiork@cpan.org>
  
=head1 COPYRIGHT & LICENSE
 
Copyright 2015, John Napiorkowski L<email:jjnapiork@cpan.org>
 
This library is free software; you can redistribute it and/or modify it under
the same terms as Perl itself.

=cut

1;
